Getting Started : contents — QuadratiK 1.0.0 documentation

Skip to main content
`Ctrl`+`K`

# Installation

## Which Python?

You’ll need Python 3.9 (except 3.9.7) or greater.

## Install using `pip`

`pip install /path/to/package`

## Dependencies

QuadratiK requires the following (arranged alphabetically):

- asyncio (>=3.4)

- matplotlib (>=3.8.2)

- nest-asyncio (>=1.5)

- numpy (>= 1.26.2)

- pandas (>= 2.1.3)

- plotly (>=5.15.0)

- scikit-learn (>= 1.3)

- scipy (>= 1.11)

- streamlit (>=1.29.0)

- tabulate (>= 0.8)

## Testing

QuadratiK uses the Python `pytest` package. To install `pytest`, please go here. To run the tests using `pytest`, please follow these instructions. Navigate to the tests folder to run the tests.